@@ -1,4 +1,4 @@
-use 5.006;
+use 5.8.5;
 use strict;
 use warnings;
 
@@ -21,7 +21,7 @@ Email::MIME - Easy MIME message parsing.
 
 =head1 VERSION
 
-version 1.903
+version 1.907
 
 =head1 SYNOPSIS
 
@@ -111,10 +111,14 @@ very long. Added to that, you have:
 
 =cut
 
-our $VERSION = '1.903';
+our $VERSION = '1.907';
 
-use vars qw[$CREATOR];
-$CREATOR = 'Email::MIME::Creator';
+our $CREATOR = 'Email::MIME::Creator';
+
+my $NO_ENCODE_RE = qr/
+  \A
+  (?:7bit|8bit|binary)\s*(?:;|$)
+/ix;
 
 sub new {
   my $self = shift->SUPER::new(@_);
@@ -296,7 +300,7 @@ sub body {
 
   return $body unless $cte;
 
-  if (!$self->force_decode_hook and $cte =~ /\A(?:7bit|8bit|binary)\z/i) {
+  if (!$self->force_decode_hook and $cte =~ $NO_ENCODE_RE) {
     return $body;
   }
 
@@ -433,7 +437,7 @@ sub header_str_set {
   $email->content_type_set( 'text/html' );
 
 Change the content type. All C<Content-Type> header attributes
-will remain in tact.
+will remain intact.
 
 =cut
 
@@ -550,7 +554,7 @@ sub body_set {
   # object. -- rjbs, 2007-07-16
   unless (((caller(1))[3] || '') eq 'Email::Simple::new') {
     $body = Email::MIME::Encodings::encode($enc, $body)
-      unless !$enc || $enc =~ /^(?:7bit|8bit|binary)\s*$/i;
+      unless !$enc || $enc =~ $NO_ENCODE_RE;
   }
 
   $self->{body_raw} = $body;
@@ -583,7 +587,7 @@ sub body_str_set {
   $email->disposition_set( 'attachment' );
 
 Alter the C<Content-Disposition> of a message. All header attributes
-will remain in tact.
+will remain intact.
 
 =cut
 
@@ -712,17 +716,20 @@ sub walk_parts {
   $walk = sub {
     my ($part) = @_;
     $callback->($part);
-    if ($part->parts > 1) {
-      my @subparts;
-      for ($part->parts) {
-        push @subparts, $walk->($_);
-      }
+
+    if ($part->subparts) {
+      my @subparts = map {; $walk->($_) } $part->subparts;
       $part->parts_set(\@subparts);
     }
+
     return $part;
   };
 
-  $walk->($self);
+  my $rv = $walk->($self);
+
+  undef $walk;
+
+  return $rv;
 }
 
 sub _compose_content_type {
